==> situare_0.6-4.tar.gz: situare-0.6/res/languages/situare_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fi_FI">
<context>
    <name>FriendListPanel</name>
    <message>
        <location filename="../../src/ui/friendlistpanel.cpp" line="44"/>
        <source>Show all</source>
        <translation>Näytä kaikki</translation>
    </message>
    <message>
        <location filename="../../src/ui/friendlistpanel.cpp" line="108"/>
        <source>Selected: %1</source>
        <translation>Valittu: %1</translation>
    </message>
</context>
<context>
    <name>GPSPositionPrivate</name>
    <message>
        <source>Unable to use GPS</source>
        <translation type="obsolete">GPS ei käytössä</translation>
    </message>
</context>
<context>
    <name>LiblocationWrapper</name>
    <message>
        <location filename="../../src/gps/liblocationwrapper.cpp" line="106"/>
        <source>Error in GPS</source>
        <translation>GPS virhe</translation>
    </message>
</context>
<context>
    <name>LoginDialog</name>
    <message>
        <location filename="../../src/ui/logindialog.cpp" line="32"/>
        <source>Login to Situare with Facebook account</source>
        <translation>Kirjaudu Situareen Facebook tunnuksilla</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="obsolete">Yhdistä</translation>
    </message>
    <message>
        <location filename="../../src/ui/logindialog.cpp" line="42"/>
        <source>Login</source>
        <translation>Kirjaudu</translation>
    </message>
    <message>
        <location filename="../../src/ui/logindialog.cpp" line="45"/>
        <source>E-mail:</source>
        <translation>Sähköposti:</translation>
    </message>
    <message>
        <location filename="../../src/ui/logindialog.cpp" line="46"/>
        <source>Password:</source>
        <translation>Salasana:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="87"/>
        <source>Automatic location update</source>
        <translation>Automaattinen paikan päivitys</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="94"/>
        <source>Situare</source>
        <translation>Situare</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="406"/>
        <location filename="../../src/ui/mainwindow.cpp" line="665"/>
        <source>Login</source>
        <translation>Kirjaudu</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="411"/>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="416"/>
        <source>GPS</source>
        <translation>GPS</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="423"/>
        <source>Auto centering</source>
        <translation>Automaattinen keskitys</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="429"/>
        <source>Main</source>
        <translation>Päävalikko</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="434"/>
        <source>Menu</source>
        <translation>Valikko</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="537"/>
        <source>GPS timeout</source>
        <translation>GPS pyyntö aikakatkaistiin</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="659"/>
        <source>Logout</source>
        <translation>Kirjaudu ulos</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Session expired. Please login again</source>
        <translation type="obsolete">Istunto vanhentunut. Kirjaudu uudelleen</translation>
    </message>
    <message>
        <source>Invalid E-mail address or password</source>
        <translation type="obsolete">Virheellinen sähköpostiosoite tai salasana</translation>
    </message>
    <message>
        <source>Update failed, please try again</source>
        <translation type="obsolete">Päivitys epäonnistui. Yritä uudelleen</translation>
    </message>
    <message>
        <source>Data retrieval failed, please try again</source>
        <oldsource>Data retrieval failed, plaease try again</oldsource>
        <translation type="obsolete">Tiedon haku epäonnistui. Yritä uudelleen</translation>
    </message>
    <message>
        <source>Address retrieval failed, please try again</source>
        <translation type="obsolete">Osoitteen haku epäonnistui. Yritä uudelleen</translation>
    </message>
    <message>
        <source>Image download failed</source>
        <translation type="obsolete">Kuvan haku epäonnistui</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../../src/ui/settingsdialog.cpp" line="41"/>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../../src/ui/settingsdialog.cpp" line="47"/>
        <source>Use automatic location update</source>
        <translation>Sijainnin automaattinen päivitys</translation>
    </message>
    <message>
        <location filename="../../src/ui/settingsdialog.cpp" line="54"/>
        <location filename="../../src/ui/settingsdialog.cpp" line="86"/>
        <source>Update interval</source>
        <translation>Päivitysväli</translation>
    </message>
    <message>
        <location filename="../../src/ui/settingsdialog.cpp" line="131"/>
        <source>%1 min</source>
        <translation>%1 min</translation>
    </message>
</context>
<context>
    <name>SituareEngine</name>
    <message>
        <location filename="../../src/engine/engine.cpp" line="140"/>
        <source>Auto centering disabled</source>
        <translation>Automaattinen keskitys pois päältä</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="180"/>
        <source>Unable to start GPS</source>
        <translation>GPS käynnistys epäonnistui</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="195"/>
        <source>Do you want to enable automatic location update with %1 min update interval?</source>
        <translation>Asetetaanko automaattinen paikan päivitys %1 minuutin välein päälle?</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="200"/>
        <source>Automatic location update enabled</source>
        <translation>Automaattinen paikan päivitys päällä</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="221"/>
        <source>Connection refused by the server</source>
        <translation>Palvelin ei vastaa pyyntöihin</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="224"/>
        <source>Connection closed by the server</source>
        <translation>Palvelin sulki yhteyden</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="227"/>
        <source>Remote server not found</source>
        <translation>Palvelinta ei löydy</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="230"/>
        <source>Connection timed out</source>
        <translation>Yhteys aikakatkaistiin</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="233"/>
        <source>Session expired. Please login again</source>
        <translation>Istunto vanhentunut. Kirjaudu uudelleen</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="241"/>
        <source>Invalid E-mail address or password</source>
        <translation>Virheellinen sähköpostiosoite tai salasana</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="244"/>
        <source>Update failed, please try again</source>
        <translation>Päivitys epäonnistui. Yritä uudelleen</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="247"/>
        <source>Data retrieval failed, please try again</source>
        <translation>Tiedon haku epäonnistui. Yritä uudelleen</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="250"/>
        <source>Address retrieval failed</source>
        <translation>Osoitteen haku epäonnistui</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="266"/>
        <source>Malformatted reply from server</source>
        <translation>Viallisesti muotoiltu serverin vastaus</translation>
    </message>
    <message>
        <source>Address retrieval failed, please try again</source>
        <translation type="obsolete">Osoitteen haku epäonnistui. Yritä uudelleen</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="253"/>
        <source>Image download failed</source>
        <translation>Kuvan haku epäonnistui</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="256"/>
        <source>Map image download failed</source>
        <translation>Karttakuvan lataaminen epäonnistui</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="260"/>
        <source>GPS initialization failed</source>
        <translation>GPS alustus epäonnistui</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="263"/>
        <source>Unknown server response</source>
        <translation>Tuntematon vastaus palvelimelta</translation>
    </message>
    <message>
        <source>JSON parsing failed, invalid JSON string</source>
        <translation type="obsolete">Virheellinen JSON, parsiminen epäonnistui</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="302"/>
        <location filename="../../src/engine/engine.cpp" line="310"/>
        <source>GPS enabled</source>
        <translation>GPS päällä</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="303"/>
        <location filename="../../src/engine/engine.cpp" line="313"/>
        <source>Auto centering enabled</source>
        <translation>Automaattinen keskitys päällä</translation>
    </message>
</context>
<context>
    <name>UpdateLocationDialog</name>
    <message>
        <location filename="../../src/ui/updatelocation/updatelocationdialog.cpp" line="34"/>
        <source>Update Location</source>
        <translation>Päivitä sijainti</translation>
    </message>
    <message>
        <location filename="../../src/ui/updatelocation/updatelocationdialog.cpp" line="71"/>
        <source>Publish on Facebook</source>
        <translation>Julkaise Facebookissa</translation>
    </message>
    <message>
        <location filename="../../src/ui/updatelocation/updatelocationdialog.cpp" line="77"/>
        <source>Send</source>
        <translation>Lähetä</translation>
    </message>
    <message>
        <location filename="../../src/ui/updatelocation/updatelocationdialog.cpp" line="82"/>
        <source>Location:</source>
        <translation>Sijainti:</translation>
    </message>
    <message>
        <location filename="../../src/ui/updatelocation/updatelocationdialog.cpp" line="42"/>
        <source>Message:</source>
        <translation>Viesti:</translation>
    </message>
</context>
<context>
    <name>UserInfo</name>
    <message>
        <source>Location update failed

Your message is saved to textbox until sending will succeed</source>
        <translatorcomment>Do \n&apos;s work properly?</translatorcomment>
        <translation type="obsolete">Sijainnin päivitys epäonnistui\n\nVistisi on tallennettu kunnes pävitys on onnistunut</translation>
    </message>
    <message>
        <location filename="../../src/ui/userinfo.cpp" line="338"/>
        <source>Location update failed, please try again</source>
        <translation>Paikkatiedon päivitys epäonnistui, yritä uudelleen</translation>
    </message>
</context>
</TS>

==> situare_1.0-0.tar.gz: situare-1.0/res/languages/situare_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fi_FI">
<context>
    <name>FriendListPanel</name>
    <message>
        <location filename="../../src/ui/friendlistpanel.cpp" line="45"/>
        <source>Show all</source>
        <translation>Näytä kaikki</translation>
    </message>
    <message>
        <location filename="../../src/ui/friendlistpanel.cpp" line="110"/>
        <source>Selected: %1</source>
        <translation>Valittu: %1</translation>
    </message>
</context>
<context>
    <name>GPSPositionPrivate</name>
    <message>
        <source>Unable to use GPS</source>
        <translation type="obsolete">GPS ei käytössä</translation>
    </message>
</context>
<context>
    <name>LiblocationWrapper</name>
    <message>
        <location filename="../../src/gps/liblocationwrapper.cpp" line="106"/>
        <source>Error in GPS</source>
        <translation>GPS virhe</translation>
    </message>
</context>
<context>
    <name>LoginDialog</name>
    <message>
        <location filename="../../src/ui/logindialog.cpp" line="32"/>
        <source>Login to Situare with Facebook account</source>
        <translation>Kirjaudu Situareen Facebook tunnuksilla</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="obsolete">Yhdistä</translation>
    </message>
    <message>
        <location filename="../../src/ui/logindialog.cpp" line="42"/>
        <source>Login</source>
        <translation>Kirjaudu</translation>
    </message>
    <message>
        <location filename="../../src/ui/logindialog.cpp" line="45"/>
        <source>E-mail:</source>
        <translation>Sähköposti:</translation>
    </message>
    <message>
        <location filename="../../src/ui/logindialog.cpp" line="46"/>
        <source>Password:</source>
        <translation>Salasana:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="838"/>
        <source>Automatic location update</source>
        <translation>Automaattinen paikan päivitys</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="84"/>
        <source>Situare</source>
        <translation>Situare</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="400"/>
        <location filename="../../src/ui/mainwindow.cpp" line="664"/>
        <source>Login</source>
        <translation>Kirjaudu</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="405"/>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="410"/>
        <source>GPS</source>
        <translation>GPS</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="417"/>
        <source>Auto centering</source>
        <translation>Automaattinen keskitys</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="423"/>
        <source>Main</source>
        <translation>Päävalikko</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="428"/>
        <source>Menu</source>
        <translation>Valikko</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="536"/>
        <source>GPS timeout</source>
        <translation>GPS pyyntö aikakatkaistiin</translation>
    </message>
    <message>
        <location filename="../../src/ui/mainwindow.cpp" line="658"/>
        <source>Logout</source>
        <translation>Kirjaudu ulos</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Session expired. Please login again</source>
        <translation type="obsolete">Istunto vanhentunut. Kirjaudu uudelleen</translation>
    </message>
    <message>
        <source>Invalid E-mail address or password</source>
        <translation type="obsolete">Virheellinen sähköpostiosoite tai salasana</translation>
    </message>
    <message>
        <source>Update failed, please try again</source>
        <translation type="obsolete">Päivitys epäonnistui. Yritä uudelleen</translation>
    </message>
    <message>
        <source>Data retrieval failed, please try again</source>
        <oldsource>Data retrieval failed, plaease try again</oldsource>
        <translation type="obsolete">Tiedon haku epäonnistui. Yritä uudelleen</translation>
    </message>
    <message>
        <source>Address retrieval failed, please try again</source>
        <translation type="obsolete">Osoitteen haku epäonnistui. Yritä uudelleen</translation>
    </message>
    <message>
        <source>Image download failed</source>
        <translation type="obsolete">Kuvan haku epäonnistui</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../../src/ui/settingsdialog.cpp" line="41"/>
        <source>Settings</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <location filename="../../src/ui/settingsdialog.cpp" line="48"/>
        <source>Use automatic location update</source>
        <translation>Sijainnin automaattinen päivitys</translation>
    </message>
    <message>
        <location filename="../../src/ui/settingsdialog.cpp" line="55"/>
        <location filename="../../src/ui/settingsdialog.cpp" line="87"/>
        <source>Update interval</source>
        <translation>Päivitysväli</translation>
    </message>
    <message>
        <location filename="../../src/ui/settingsdialog.cpp" line="120"/>
        <source>%1 min</source>
        <translation>%1 min</translation>
    </message>
</context>
<context>
    <name>SituareEngine</name>
    <message>
        <location filename="../../src/engine/engine.cpp" line="136"/>
        <source>Auto centering disabled</source>
        <translation>Automaattinen keskitys pois päältä</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="186"/>
        <source>Unable to start GPS</source>
        <translation>GPS käynnistys epäonnistui</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="199"/>
        <source>Do you want to enable automatic location update with %1 min update interval?</source>
        <translation>Asetetaanko automaattinen paikan päivitys %1 minuutin välein päälle?</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="204"/>
        <source>Automatic location update enabled</source>
        <translation>Automaattinen paikan päivitys päällä</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="233"/>
        <source>Unknown server error</source>
        <translation>Tuntematon palvelinvirhe</translation>
    </message>
    <message>
        <source>Missing argument from request</source>
        <translation type="obsolete">Pyynnöstä puuttuu parametri</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="239"/>
        <source>Missing parameter from request</source>
        <translation>Pyynnöstä puuttuu parametri</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="241"/>
        <source>Connection refused by the server</source>
        <translation>Palvelin ei vastaa pyyntöihin</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="247"/>
        <source>Connection closed by the server</source>
        <translation>Palvelin sulki yhteyden</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="253"/>
        <source>Remote server not found</source>
        <translation>Palvelinta ei löydy</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="259"/>
        <source>Connection timed out</source>
        <translation>Yhteys aikakatkaistiin</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="265"/>
        <source>No network connection</source>
        <translation type="unfinished">Ei verkkoyhteyttä</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="269"/>
        <source>Session expired. Please login again</source>
        <translation>Istunto vanhentunut. Kirjaudu uudelleen</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="277"/>
        <source>Invalid E-mail address or password</source>
        <translation>Virheellinen sähköpostiosoite tai salasana</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="282"/>
        <source>Update failed, please try again</source>
        <translation>Päivitys epäonnistui. Yritä uudelleen</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="286"/>
        <source>Data retrieval failed, please try again</source>
        <translation>Tiedon haku epäonnistui. Yritä uudelleen</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="292"/>
        <source>Address retrieval failed</source>
        <translation>Osoitteen haku epäonnistui</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="305"/>
        <source>Malformatted reply from server</source>
        <translation>Viallisesti muotoiltu serverin vastaus</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="311"/>
        <source>Address server not responding</source>
        <translation>Osoitepalvelin ei vastaa</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="479"/>
        <source>Automatic location update</source>
        <translation>Automaattinen paikan päivitys</translation>
    </message>
    <message>
        <source>Geolocation server not responding</source>
        <translation type="obsolete">Geolokaatio serveri ei vastaa</translation>
    </message>
    <message>
        <source>Geolocation request failed, please try again</source>
        <translation type="obsolete">Geolokaatio pyyntö epäonnistui.Yritä uudelleen</translation>
    </message>
    <message>
        <source>Invalid lat/lon value, please try again</source>
        <translation type="obsolete">Virheellinen lat/lon arvo. Yritä uudelleen</translation>
    </message>
    <message>
        <source>Automatic location update.</source>
        <translation type="obsolete">Automaattinen paikkatiedon päivitys.</translation>
    </message>
    <message>
        <source>Address retrieval failed, please try again</source>
        <translation type="obsolete">Osoitteen haku epäonnistui. Yritä uudelleen</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="295"/>
        <source>Image download failed</source>
        <translation>Kuvan haku epäonnistui</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="298"/>
        <source>Map image download failed</source>
        <translation>Karttakuvan lataaminen epäonnistui</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="302"/>
        <source>GPS initialization failed</source>
        <translation>GPS alustus epäonnistui</translation>
    </message>
    <message>
        <source>Unknown server response</source>
        <translation type="obsolete">Tuntematon vastaus palvelimelta</translation>
    </message>
    <message>
        <source>JSON parsing failed, invalid JSON string</source>
        <translation type="obsolete">Virheellinen JSON, parsiminen epäonnistui</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="349"/>
        <location filename="../../src/engine/engine.cpp" line="357"/>
        <source>GPS enabled</source>
        <translation>GPS päällä</translation>
    </message>
    <message>
        <location filename="../../src/engine/engine.cpp" line="350"/>
        <location filename="../../src/engine/engine.cpp" line="360"/>
        <source>Auto centering enabled</source>
        <translation>Automaattinen keskitys päällä</translation>
    </message>
</context>
<context>
    <name>UpdateLocationDialog</name>
    <message>
        <location filename="../../src/ui/updatelocation/updatelocationdialog.cpp" line="34"/>
        <source>Update Location</source>
        <translation>Päivitä sijainti</translation>
    </message>
    <message>
        <location filename="../../src/ui/updatelocation/updatelocationdialog.cpp" line="74"/>
        <source>Publish on Facebook</source>
        <translation>Julkaise Facebookissa</translation>
    </message>
    <message>
        <location filename="../../src/ui/updatelocation/updatelocationdialog.cpp" line="80"/>
        <source>Send</source>
        <translation>Lähetä</translation>
    </message>
    <message>
        <location filename="../../src/ui/updatelocation/updatelocationdialog.cpp" line="82"/>
        <source>Location:</source>
        <translation>Sijainti:</translation>
    </message>
    <message>
        <location filename="../../src/ui/updatelocation/updatelocationdialog.cpp" line="43"/>
        <source>Message:</source>
        <translation>Viesti:</translation>
    </message>
</context>
<context>
    <name>UserInfo</name>
    <message>
        <source>Location update failed

Your message is saved to textbox until sending will succeed</source>
        <translatorcomment>Do \n&apos;s work properly?</translatorcomment>
        <translation type="obsolete">Sijainnin päivitys epäonnistui\n\nVistisi on tallennettu kunnes pävitys on onnistunut</translation>
    </message>
    <message>
        <location filename="../../src/ui/userinfo.cpp" line="353"/>
        <source>Location update failed, please try again</source>
        <translation>Paikkatiedon päivitys epäonnistui, yritä uudelleen</translation>
    </message>
</context>
</TS>
